function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import { FILL_COLOR_MAP } from '../../utils/accessibility';
/**
 * Tiny inline component used to draw attention to an item's state or status.
 * @param {Object} props - Properties passed to component
 * @returns {ReactElement}
 */

var Badge = function Badge(_ref) {
  var backgroundColor = _ref.backgroundColor,
      children = _ref.children,
      color = _ref.color,
      testSection = _ref.testSection;
  var classes = classNames(_defineProperty({
    'oui-badge': true
  }, "oui-badge--".concat(color), color)); // ensure valid backgroundColor name
  // (in the case that propType errors are ignored)

  var badgeFillColor = backgroundColor && color === 'default' && (Object.keys(FILL_COLOR_MAP).includes(backgroundColor) ? FILL_COLOR_MAP[backgroundColor] : null);
  return React.createElement("span", {
    "data-oui-component": true,
    className: classes,
    style: {
      backgroundColor: badgeFillColor
    },
    "data-test-section": testSection
  }, children);
};

Badge.propTypes = {
  /** Color to use for the background of the token */
  backgroundColor: PropTypes.oneOf(Object.keys(FILL_COLOR_MAP)),

  /** Text that appears within the component */
  children: PropTypes.node.isRequired,

  /** Various color schemes */
  color: PropTypes.oneOf(['default', 'draft', 'live', 'primary', 'plain', 'purple', 'bad-news']),

  /** Hook for automated JavaScript tests */
  testSection: PropTypes.string
};
Badge.defaultProps = {
  color: 'default'
};
export default Badge;