import _pt from "prop-types";
import React from 'react';
import classnames from 'classnames';
import { FILL_COLOR_MAP } from '../../utils/accessibility';
var DEFAULT_FILL_COLOR_NAME = 'default';

var RangeSlider = function RangeSlider(_ref) {
  var _ref$fillColorName = _ref.fillColorName,
      fillColorName = _ref$fillColorName === void 0 ? DEFAULT_FILL_COLOR_NAME : _ref$fillColorName,
      _ref$isDisabled = _ref.isDisabled,
      isDisabled = _ref$isDisabled === void 0 ? false : _ref$isDisabled,
      onChange = _ref.onChange,
      testSection = _ref.testSection,
      _ref$useOffForLabel = _ref.useOffForLabel,
      useOffForLabel = _ref$useOffForLabel === void 0 ? false : _ref$useOffForLabel,
      value = _ref.value;
  var rangeClasses = classnames({
    'oui-rangeslider': true,
    'oui-rangeslider--disabled': isDisabled
  }); // ensure valid fillColor name (in the case that propType errors are ignored)

  var validFillColorName = Object.keys(FILL_COLOR_MAP).includes(fillColorName) ? fillColorName : DEFAULT_FILL_COLOR_NAME;
  var fillColor = FILL_COLOR_MAP[validFillColorName];
  return React.createElement("div", {
    className: rangeClasses,
    "data-test-section": testSection
  }, React.createElement("div", {
    className: "oui-grid"
  }, React.createElement("div", {
    className: "oui-grid__cell position--relative"
  }, React.createElement("div", {
    className: "range-labels flex"
  }, React.createElement("label", {
    className: "oui-label muted flush flex--1"
  }, useOffForLabel ? 'Off' : '0%'), React.createElement("label", {
    className: "oui-label muted flush"
  }, "100%")), React.createElement("div", {
    className: "range-display"
  }, React.createElement("svg", {
    preserveAspectRatio: "none",
    xmlns: "http://www.w3.org/2000/svg",
    width: "100",
    height: "100",
    viewBox: "0 0 100 100"
  }, React.createElement("path", {
    fill: fillColor,
    d: "M0 100h100V0z",
    shapeRendering: "geometricPrecision"
  })), React.createElement("svg", {
    preserveAspectRatio: "none",
    xmlns: "http://www.w3.org/2000/svg",
    width: "100",
    height: "100",
    viewBox: "0 0 100 100",
    style: {
      position: 'absolute',
      left: 0,
      top: 0
    }
  }, React.createElement("path", {
    d: "M".concat(value, " 100H100V0L").concat(value, " ").concat(100 - value - 1, "z"),
    fill: "white",
    opacity: "0.9",
    shapeRendering: "geometricPrecision"
  }))), React.createElement("div", {
    className: "range-grid"
  }, React.createElement("div", {
    className: "gridline grid-1"
  }), React.createElement("div", {
    className: "gridline grid-2"
  }), React.createElement("div", {
    className: "gridline grid-3"
  }), React.createElement("div", {
    className: "gridline grid-4"
  }), React.createElement("div", {
    className: "gridline grid-5"
  }), React.createElement("div", {
    className: "gridline gridline-half grid-h1"
  }), React.createElement("div", {
    className: "gridline gridline-half grid-h2"
  }), React.createElement("div", {
    className: "gridline gridline-half grid-h3"
  }), React.createElement("div", {
    className: "gridline gridline-half grid-h4"
  })), React.createElement("input", {
    className: "hard position--relative width--1-1",
    "data-traffic-group": "1",
    type: "range",
    min: "0",
    max: "100",
    step: "1",
    value: value,
    onChange: onChange,
    disabled: isDisabled
  }))));
};

RangeSlider.propTypes = {
  fillColorName: _pt.any,
  isDisabled: _pt.bool,
  onChange: _pt.func.isRequired,
  testSection: _pt.string,
  useOffForLabel: _pt.bool,
  value: _pt.number.isRequired
};
export default RangeSlider;