function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import classNames from 'classnames';
import PropTypes from 'prop-types';
import { Resizable } from 're-resizable';
/**
 * Sidebar
 *
 * Example:
 *
 *  <Sidebar
 *    anchor='left'
 *    border={ true }
 *    docked={ true }
 *    isOpen={ false }
 *    width={ 100 }>
 *     sidebar content goes here
 *  </Sidebar>
 *
 */

var Sidebar = function Sidebar(props) {
  var anchor = props.anchor,
      border = props.border,
      boxShadow = props.boxShadow,
      children = props.children,
      docked = props.docked,
      sticky = props.sticky,
      isResizable = props.isResizable,
      isOpen = props.isOpen,
      width = props.width,
      minWidth = props.minWidth,
      maxWidth = props.maxWidth,
      testSection = props.testSection;
  var baseClasses = classNames('background--white', 'flex', 'flex--1', 'flex--column', 'oui-sidebar', 'overflow--hidden');
  var classes = classNames(baseClasses, {
    'border--right': border && anchor === 'left',
    'border--left': border && anchor === 'right',
    'oui-shadow': boxShadow,
    'position--relative': docked,
    'position--absolute height--1-1': !docked && !sticky,
    'position--fixed height--1-1': !docked && sticky,
    'visibility--hidden': !isOpen
  });
  var anchorPosition = anchor === 'left' ? -1 * width : 0;

  var styles = _defineProperty({
    width: isOpen ? width : 0,
    maxWidth: isOpen ? width : 0
  }, anchor, isOpen ? 0 : anchorPosition);

  var resizeEnabled = {
    top: false,
    right: anchor === 'left' && isResizable,
    bottom: false,
    left: anchor === 'right' && isResizable,
    topRight: false,
    bottomRight: false,
    bottomLeft: false,
    topLeft: false
  };
  var defaultSize = {
    width: isOpen ? width : 0,
    height: 'auto'
  };

  if (isResizable && !docked) {
    return React.createElement(Resizable, {
      defaultSize: defaultSize,
      minWidth: minWidth,
      maxWidth: maxWidth,
      "data-oui-component": true,
      "data-test-section": testSection,
      className: classes,
      style: styles,
      enable: resizeEnabled
    }, isOpen && children);
  }

  return React.createElement("div", {
    "data-oui-component": true,
    "data-test-section": testSection,
    className: classes,
    style: styles
  }, isOpen && children);
};

Sidebar.defaultProps = {
  anchor: 'right',
  border: false,
  docked: false,
  sticky: false,
  isResizable: false,
  isOpen: false,
  width: 0
};
Sidebar.propTypes = {
  /**
   * Determines whether the sidebar should render on
   * the left or right side of the page
   */
  anchor: PropTypes.oneOf(['left', 'right']),

  /** Determines if the sidebar should have a border */
  border: PropTypes.bool,

  /** Determines if the sidebar should have a box shadow */
  boxShadow: PropTypes.bool,

  /** Sidebar children */
  children: PropTypes.node.isRequired,

  /**
   * Docked sidebars push page-content to left or right when open.
   * Un-docked sidebars render open over page-content (i.e postition absolute)
   */
  docked: PropTypes.bool,

  /**
   * Sticky sidebars render open over page-content (i.e postition fixed).
   * And maintain their position on the screen on scroll.
   * This prop is only in effect when docked is false.
   */
  isOpen: PropTypes.bool,

  /** Determines if the sidebar is visible */
  isResizable: PropTypes.bool,

  /** When resizable, The maximum pixel width of the sidebar */
  maxWidth: PropTypes.number,

  /** When resizable, The minimum pixel width of the sidebar */
  minWidth: PropTypes.number,

  /** Determines if the sidebar is resizable.
      Resizable only works for undocked sidebars. */
  sticky: PropTypes.bool,

  /** Hook for automated JavaScript tests */
  testSection: PropTypes.string,

  /** The pixel width of the sidebar */
  width: PropTypes.number.isRequired
};
export default Sidebar;