var _SORT_ORDER_DIRECTION;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import Button from '../../Button/index';
import ArrowsInline from '../../ArrowsInline/index';
var SORT_ORDERS = {
  ASC: 'asc',
  DESC: 'desc'
};
var SORT_ORDER_DIRECTION = (_SORT_ORDER_DIRECTION = {}, _defineProperty(_SORT_ORDER_DIRECTION, SORT_ORDERS.ASC, 'up'), _defineProperty(_SORT_ORDER_DIRECTION, SORT_ORDERS.DESC, 'down'), _SORT_ORDER_DIRECTION);

var TH = function TH(_ref) {
  var children = _ref.children,
      colSpan = _ref.colSpan,
      isCollapsed = _ref.isCollapsed,
      isNumerical = _ref.isNumerical,
      sorting = _ref.sorting,
      testSection = _ref.testSection,
      textAlign = _ref.textAlign,
      width = _ref.width;
  var classes = classNames({
    'oui-numerical': isNumerical,
    'oui-cell-collapse': isCollapsed
  });
  var styles = {
    width: width,
    textAlign: textAlign
  };
  var tableHeaderContent = sorting.canSort ? React.createElement(Button, {
    onClick: sorting.handleSort,
    style: "unstyled",
    testSection: "table-header-sort-button"
  }, children, React.createElement("span", {
    className: "push-half--left"
  }, React.createElement(ArrowsInline, {
    direction: SORT_ORDER_DIRECTION[sorting.order],
    testSection: "table-header-sort-indicator"
  }))) : children;
  return React.createElement("th", {
    className: classes,
    "data-test-section": testSection,
    style: styles,
    colSpan: colSpan
  }, tableHeaderContent);
};

TH.propTypes = {
  /** Content within the `Table.TH` component */
  children: PropTypes.node,

  /** Number of columns that the cell should span */
  colSpan: PropTypes.number,

  /**
    Tell the cell to take up the least amount of width possible. This only
    works well if the table layout is `auto`, not `fixed`.
  */
  isCollapsed: PropTypes.bool,

  /** Right-align the cell if the contents are numerical */
  isNumerical: PropTypes.bool,

  /** Sorting options */
  sorting: PropTypes.shape({
    /** Indicate if this column should be sortable */
    canSort: PropTypes["boolean"],

    /** Function that handles sorting */
    handleSort: PropTypes.func,

    /** Current order. One of 'asc' or 'desc' */
    order: PropTypes.oneOf([SORT_ORDERS.ASC, SORT_ORDERS.DESC])
  }),

  /** Hook for automated JavaScript tests */
  testSection: PropTypes.string,

  /** Text alignment */
  textAlign: PropTypes.oneOf(['center', 'right', 'left']),

  /** A number with a unit that becomes the width of the `Table` cell */
  width: PropTypes.string
};
TH.defaultProps = {
  isCollapsed: false,
  isNumerical: false,
  sorting: {
    canSort: false
  }
};
TH.propTypes = {
  /** Checks that all the info for sorting is present.
   *  @param {Object} props Object of props
   *  @returns {Error} Error or null
   */
  sorting: function verifyHandleSortExists(props) {
    if (props.sorting.canSort && !props.sorting.handleSort) {
      return new Error('Must pass a sorting function.');
    }

    if (props.sorting.canSort && !props.sorting.order) {
      return new Error('Must pass a sorting direction.');
    }

    return null;
  }
};
TH.displayName = 'Table.TH';
export default TH;